#
# spec file for package libstorage
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           libstorage
Version:        2.26.12
Release:        12.1
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Source:         libstorage-%{version}.tar.bz2

Prefix:         /usr

BuildRequires:  boost-devel
BuildRequires:  dejagnu
BuildRequires:  doxygen
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  libxml2-devel
BuildRequires:  python-devel
BuildRequires:  ruby
BuildRequires:  ruby-devel
BuildRequires:  swig

Summary:        Library for storage management
License:        GPL-2.0
Group:          System/Libraries
Url:            http://en.opensuse.org/Portal:Libstorage

%description
This package contains libstorage, a library for storage management.

%{!?python_sitelib: %global python_sitelib %(%{__python} -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%{!?python_sitearch: %global python_sitearch %(%{__python} -c "from distutils.sysconfig import get_python_lib; print get_python_lib(1)")}
%{!?py_requires: %global py_requires Requires: python}

%if 0%{?ruby_sitelib} == 0
%if 0%{?fedora_version} || 0%{?centos_version} || 0%{?rhel_version} || 0%{?fedora} || 0%{?rhel}
%{!?ruby_sitelib: %global ruby_sitelib %(ruby -r rbconfig -e 'vd = Config::CONFIG["vendorlibdir"]; print(vd ? vd : Config::CONFIG["sitelibdir"])')}
%{!?ruby_sitearch: %global ruby_sitearch %(ruby -r rbconfig -e 'vad = Config::CONFIG["vendorarchdir"]; print(vad ? vad : Config::CONFIG["sitearchdir"])')}
%{!?ruby_vendor: %global ruby_vendor %(ruby -r rbconfig -e 'vad = Config::CONFIG["vendor"]; print(vad ? vad : Config::CONFIG["vendor"])')}
%endif
%endif

%prep
%setup -n libstorage-%{version}

%build
export CFLAGS="$RPM_OPT_FLAGS -DNDEBUG"
export CXXFLAGS="$RPM_OPT_FLAGS -DNDEBUG"

aclocal
libtoolize --force --automake --copy
autoheader
automake --add-missing --copy
autoconf

%{?suse_update_config:%{suse_update_config -f}}
%if 0%{?fedora_version} || 0%{?centos_version}
CXXFLAGS="-I/usr/include/libxml2" \
%else
%if 0%{?rhel_version} >= 500 && 0%{?rhel_version} < 600
CXXFLAGS="-I/usr/include/libxml2 -I/usr/include/c++/4.1.1/tr1" \
%endif
%endif

./configure --libdir=%{_libdir} --prefix=%{prefix} --mandir=%{_mandir} --disable-silent-rules
make %{?jobs:-j%jobs}

%ifarch s390 s390x
sed -i -e 's/DEVICE_NAMES=".*"/DEVICE_NAMES="path"/' data/sysconfig.storage-libstorage
%endif

%check
%if ! 0%{?qemu_user_space_build}
LOCALEDIR=$RPM_BUILD_ROOT/usr/share/locale make check
%endif

%install
make install DESTDIR="$RPM_BUILD_ROOT"

install -d -m 755 $RPM_BUILD_ROOT/run/libstorage
touch $RPM_BUILD_ROOT/run/libstorage/lock

%{find_lang} libstorage

rm -f $RPM_BUILD_ROOT/%{python_sitearch}/_storage.a
rm -f $RPM_BUILD_ROOT/%{python_sitearch}/_storage.la
%if 0%{?suse_version}
%if "%{?rb_vendorarchdir}" != ""
rm -f $RPM_BUILD_ROOT/%{rb_vendorarchdir}/storage.la
%else
rm -f $RPM_BUILD_ROOT/%{rb_vendorarch}/storage.la
%endif
%endif
%if 0%{?mandriva_version}
rm $RPM_BUILD_ROOT/%{ruby_sitearchdir}/storage.la
%endif
%if 0%{?fedora_version} || 0%{?rhel_version} || 0%{?centos_version}
rm $RPM_BUILD_ROOT/%{ruby_sitearch}/storage.la
%endif

%clean
rm -rf "$RPM_BUILD_ROOT"

%package -n libstorage7

Requires:       coreutils
Suggests:       cryptsetup
Requires:       device-mapper
Suggests:       dmraid
Requires:       grep
Requires:       lsscsi >= 0.26
Suggests:       lvm2
Suggests:       mdadm >= 3.3
Suggests:       multipath-tools
Requires:       parted >= 3.1
Requires:       udev
Requires:       util-linux >= 2.16
%ifarch s390 s390x
Requires:       s390-tools
%endif

%if 0%{?suse_version}
PreReq:         %fillup_prereq
%endif
Obsoletes:      yast2-storage-lib
# expands to Obsoletes: libstorage libstorage1 libstorage2 libstorage3...
Obsoletes:      libstorage7 < %{version}
Obsoletes:      libstorage %(echo `seq -s " " -f "libstorage%.f" $((7 - 1))`)
Summary:        Library for storage management
Group:          System/Libraries

%description -n libstorage7
This package contains libstorage, a library for storage management.

Authors:
--------
    Thomas Fehr <fehr@suse.de>
    Arvin Schnell <aschnell@suse.de>

%files -n libstorage7 -f libstorage.lang
%defattr(-,root,root)
%{_libdir}/libstorage.so.*
%ghost /run/libstorage
/var/adm/fillup-templates/sysconfig.storage-libstorage
%doc %dir %{prefix}/share/doc/packages/libstorage
%doc %{prefix}/share/doc/packages/libstorage/AUTHORS
%doc %{prefix}/share/doc/packages/libstorage/COPYING

%post -n libstorage7
/sbin/ldconfig
%if 0%{?suse_version}
%{fillup_only -an storage}
%endif

%postun -n libstorage7
/sbin/ldconfig

%package -n libstorage-devel

Requires:       gcc-c++
Requires:       libstdc++-devel
Requires:       libstorage7 = %version
Requires:       libxml2-devel
Summary:        Header files and documentation for libstorage
Group:          Development/Languages/C and C++

%description -n libstorage-devel
This package contains header files and documentation for developing with
libstorage.

Authors:
--------
    Thomas Fehr <fehr@suse.de>
    Arvin Schnell <aschnell@suse.de>

%files -n libstorage-devel
%defattr(-,root,root)
%{_libdir}/libstorage.la
%{_libdir}/libstorage.so
%{prefix}/include/storage
%doc %{prefix}/share/doc/packages/libstorage/autodocs
%doc %{prefix}/share/doc/packages/libstorage/examples

%package -n libstorage-python

Requires:       libstorage7 = %version
%{py_requires}
Summary:        Python bindings for libstorage
Group:          System/Libraries

%description python
This package contains Python bindings for libstorage.

Authors:
--------
    Arvin Schnell <aschnell@suse.de>

%files -n libstorage-python
%defattr(-,root,root)
%{python_sitelib}/storage.py*
%attr(755,root,root) %{python_sitearch}/_storage.so

%package -n libstorage-ruby

Requires:       libstorage7 = %version
Summary:        Ruby bindings for libstorage
Group:          System/Libraries

%description ruby
This package contains Ruby bindings for libstorage.

Authors:
--------
    Thomas Fehr <fehr@suse.de>
    Arvin Schnell <aschnell@suse.de>

%files -n libstorage-ruby
%defattr(-,root,root)
%if 0%{?suse_version}
%if "%{?rb_vendorarchdir}" != ""
%{rb_vendorarchdir}/storage.so
%else
%{rb_vendorarch}/storage.so
%endif
%endif
%if 0%{?mandriva_version}
%{ruby_sitearchdir}/storage.so
%endif
%if 0%{?fedora_version} || 0%{?rhel_version} || 0%{?centos_version}
%{ruby_sitearch}/storage.so
%endif

%package -n libstorage-testsuite

Requires:       libstorage7 = %version
Summary:        Testsuite for libstorage
Group:          Development/Tools/Other

%description -n libstorage-testsuite
This package contains testsuite programs for libstorage.

Authors:
--------
    Arvin Schnell <aschnell@suse.de>

%files testsuite
%defattr(-,root,root)
%dir /usr/lib/libstorage
/usr/lib/libstorage/testsuite-real

%changelog
* Mon Feb 13 2017 aschnell@suse.com
- omit option --zero for lvcreate when creating thin provisioned
  volumes (bsc#968346)
- 2.26.12
* Tue Jan 24 2017 shundhammer@suse.de
- Fix out of range exception if root is dm-encrypted (fate#320215)
- 2.26.11
* Thu Oct  6 2016 shundhammer@suse.de
- Don't accept 'format' flag if volume is in use (bsc#996007)
- 2.26.10
* Thu Sep 22 2016 shundhammer@suse.de
- Don't suppress subvol commit actions after resize (bsc#1000165)
- 2.26.9
* Wed Sep  7 2016 aschnell@suse.com
- improved message for creating volumes with a filesystem but
  without a mountpoint (bsc#996208)
- 2.26.8
* Tue Sep  6 2016 aschnell@suse.com
- merged pull request to not set boot flag on DASDs (see
  bsc#935127)
- 2.26.7
* Wed Aug 10 2016 aschnell@suse.com
- added partition id string for GPT BIOS (bsc#991252)
- 2.26.6
* Fri Aug  5 2016 aschnell@suse.com
- fixed removing volume groups with encrypted physical volumes
  (bsc#989750)
- 2.26.5
* Wed Jul 13 2016 shundhammer@suse.de
- Use stdin, not tmp files for passwords (bsc#986971)
- 2.26.4
* Thu May 19 2016 aschnell@suse.com
- call parted with --wipesignatures when creating partitions to
  avoid auto-assembly of old MD RAIDs (fate#319893, bsc#943623)
- 2.26.3
* Fri Apr 15 2016 aschnell@suse.com
- call udevadm settle after call of parted (bsc#975162)
- 2.26.2
* Thu Apr  7 2016 gs@suse.de
- provide information about DASD format and type
  (related to bnc#958893)
- 2.26.1
* Wed Apr  6 2016 aschnell@suse.com
- drop support for GPT with sync to MBR (fate#317849)
- 2.25.37
* Thu Mar 10 2016 dvaleev@suse.com
- Add PowerNV support (boo#970582)
- 2.25.36
* Wed Oct 28 2015 shundhammer@suse.de
- Added fixed lt.po again that had broken build
- 2.25.35
* Tue Oct 27 2015 lslezak@suse.cz
- repeat the btrfs file system detection when a race condition in
  the "btrfs" command is detected (bsc#948247)
* Tue Oct 27 2015 shundhammer@suse.de
- Added --zero=y --yes to 'lvcreate' call to prevent interactive
  prompt (bsc#948539)
- Temporarily removed lt.po that breaks build
- 2.25.34
* Thu Sep 24 2015 aschnell@suse.com
- detect corrupt backup GPT in parted output (see bsc#946673)
* Wed Sep 23 2015 aschnell@suse.com
- changed some requires to suggests (bsc#907331 and bsc#915097)
- 2.25.33
* Fri Sep 18 2015 aschnell@suse.com
- fixed detection for parted reporting that GPT does not use
  complete disk (bsc#946013)
- 2.25.32
* Wed Sep  9 2015 shundhammer@suse.de
- Make sure no volumes are left behind when writing a new disk
  label for multipath (bsc#888513)
- 2.25.31
* Tue Sep  1 2015 aschnell@suse.com
- allow to override EFI detection with env var EFI (bsc#937067)
- 2.25.30
* Tue Aug 25 2015 shundhammer@suse.de
- Properly initialize _doThrow flag in SystemCmd default constructor
- Catch exception if boot.quota command not found (bsc#942324)
- 2.25.29
* Thu Aug 20 2015 shundhammer@suse.de
- Handle 'command not found' for /sbin/btrfs gracefully (bsc#936710)
- New exception class CommandNotFoundException for the general case
- 2.25.28
* Wed Jul 22 2015 shundhammer@suse.de
- Don't throw exception for all kinds of parted stderr output
  (bnc#938561, bnc#938572)
- 2.25.27
* Mon Jul 13 2015 dmueller@suse.com
- skip checks on qemu user mode builds (bsc#937215)
* Fri Jul 10 2015 ancor@suse.com
- remove partition from efi before destroying it on GPT disks
  (bnc#929677, bnc#870211)
- 2.25.26
* Mon Jun 29 2015 jreidinger@suse.com
- Read subvolumes information even in readonly mode (bnc#935769)
- 2.25.25
* Mon Jun 22 2015 shundhammer@suse.de
- Catch I/O errors while probing disks with parted (bsc#934640)
- 2.25.24
* Fri Jun 12 2015 aschnell@suse.de
- added flag nocow to Subvolume class (API change) (fate#316718)
- generate python and ruby bindings from common swig interface
  file, renaming python module
- 2.25.23
* Mon Jun  8 2015 schubi@suse.de
- Taking shutdown option for multipathd stopping (bnc#928572)
- 2.25.22
* Tue Jun  2 2015 aschnell@suse.de
- enable mounting subvolumes of btrfs root filesystem during
  installation after grub2 is fixed (for fate#318392)
* Fri May 29 2015 aschnell@suse.de
- fixed access to uninitialized memory (see bsc#932306)
- 2.25.21
* Mon May 18 2015 mvidner@suse.com
- Added stub error strings. Now you should see
  "DISK_PARTITION_NOT_FOUND" instead of "-1008".
* Tue Feb 17 2015 aschnell@suse.de
- mount subvolumes of btrfs root filesystem during installation
  (for fate#318392)
* Thu Feb 12 2015 aschnell@suse.de
- added commit callbacks (for fate#318392)
- 2.25.20
* Mon Feb  9 2015 dvaleev@suse.com
- Don't create gpt_sync_mbr on Power8, machine is capable to boot
  from GPT (bsc#916935)
- 2.25.19
* Tue Dec  9 2014 aschnell@suse.de
- restructured source files
* Tue Oct 14 2014 aschnell@suse.de
- obsolete ancient version of libstorage (bsc#900875)
* Tue Oct  7 2014 aschnell@suse.de
- use xfs_repair instead of extinct xfs_check (bsc#899930)
* Mon Oct  6 2014 aschnell@suse.de
- extended testsuite
* Thu Oct  2 2014 aschnell@suse.de
- detect iso9660 and udf filesystems (fate#317247)
- 2.25.18
* Thu Oct  2 2014 aschnell@suse.de
- in general use wipefs to remove old signatures
- 2.25.17
* Mon Sep 29 2014 aschnell@suse.de
- updated translations (bsc#877325)
- 2.25.16
* Thu Sep 25 2014 aschnell@suse.de
- sort partitions after certain remove steps (bsc#898362)
* Mon Sep 22 2014 aschnell@suse.de
- treat disks with implicit partition table as read-only
  (bsc#894585)
* Tue Sep 16 2014 aschnell@suse.de
- fixed using DM disks for LVM (bnc#896729)
- 2.25.15
* Tue Sep  9 2014 aschnell@suse.de
- disallow shrinking of btrfs filesystems (bnc#894832)
* Fri Sep  5 2014 aschnell@suse.de
- improved testmode
* Thu Aug 14 2014 aschnell@suse.de
- per default zero (wipefs) new partitions (bnc#891956)
* Tue Jul 29 2014 aschnell@suse.de
- also remove crypt devices during deactivation (bnc#888128)
* Mon Jul 28 2014 aschnell@suse.de
- fixed used-by information for multipath with LVM (bnc#888838)
* Mon Jul 21 2014 aschnell@suse.de
- ignore default subvolume during subvolume detection (bnc#882982)
- fixed encryption detection (see bnc#888128)
* Wed Jul 16 2014 aschnell@suse.de
- fixed check for parted errors (see bnc#886005)
* Wed Jul  9 2014 aschnell@suse.de
- call tune2fs when changing data mode for ext3 and ext4 root
  filesystem (bnc#886240)
* Mon Jul  7 2014 rneuhauser@sigpipe.cz
- configure{,.ac} uses python2-config to find python headers, libs
* Wed Jun 11 2014 dvaleev@suse.com
- Print different messages for msdos and gpt PReP partitions
- 2.25.14
* Mon May 26 2014 aschnell@suse.de
- fixed fstab handling of multiple swap devices (bnc#879890)
* Tue May 20 2014 aschnell@suse.de
- create version 5 superblock with mkfs.xfs to have bigger ACLs
  (see fate#317042)
- 2.25.13
* Thu May 15 2014 dvaleev@suse.com
- add GPT PReP support (Boot partition for POWER architecture)
* Mon May  5 2014 aschnell@suse.de
- fixed parsing of /proc/mdstat to properly detect IMSM and DDF
  containers (bnc#858226)
* Tue Apr 22 2014 aschnell@suse.de
- moved lock file to /run/libstorage
* Fri Apr 11 2014 aschnell@suse.de
- removed workaround for blkid file-system misdetection
  (bnc#869359)
- 2.25.12
* Tue Apr  8 2014 aschnell@suse.de
- adapted to lsscsi output change concerning FCoE
* Mon Apr  7 2014 dvaleev@suse.com
- Always wipe PReP partition (bnc#870590)
* Tue Mar 25 2014 aschnell@suse.de
- fixed type visibility for gcc 4.9
* Tue Mar 25 2014 aschnell@suse.de
- fixed btrfs subvolume detection (bnc#869764)
- 2.25.11
* Wed Mar 19 2014 aschnell@suse.de
- added workaround for blkid file-system misdetection (bnc#864703)
* Tue Mar 18 2014 aschnell@suse.de
- added workaround for parted cylinder discrepancy (bnc#866535)
* Mon Mar 17 2014 aschnell@suse.de
- include PPC PReP in commit text (see bnc#867345)
- 2.25.10
* Fri Mar 14 2014 aschnell@suse.de
- do not create gpt_sync_mbr on ppc64le (bnc#868227)
- replaced env.var. LIBSTORAGE_ENFORCE_EFI by LIBSTORAGE_EFI
* Mon Mar  3 2014 aschnell@suse.de
- fixed partition end cylinder calculation (bnc#866149)
* Fri Feb 28 2014 aschnell@suse.de
- adjust start cylinder of partitions on ECKD DASDs (bnc#866149)
* Wed Feb 26 2014 aschnell@suse.de
- fixed formatting after changing filesystem type (bnc#848655)
* Mon Feb 24 2014 aschnell@suse.de
- use parted for ECKD DASDs (fate#313075)
- 2.25.9
* Fri Feb 21 2014 aschnell@suse.de
- provide number and device name in PartitionSlotInfo
- use RegionInfo in libstorage API
- 2.25.8
* Mon Feb 17 2014 aschnell@suse.de
- fixed setting filesystem label for btrfs during installation
  (bnc#862409)
* Thu Feb 13 2014 aschnell@suse.de
- extended testsuite
* Thu Feb 13 2014 aschnell@suse.de
- removed unfit allocation variable from LvmLvInfo
* Thu Feb  6 2014 aschnell@suse.de
- allow to set filesystem label for mounted btrfs (see bnc#862409)
* Wed Feb  5 2014 aschnell@suse.de
- fixed package obsoletes (bnc#861747)
* Mon Jan 27 2014 aschnell@suse.de
- don't check exit code of parted
* Thu Jan 23 2014 aschnell@suse.de
- adapted fat resizing to parted 3.1 (part of fate#316110)
- 2.25.7
* Wed Jan 22 2014 aschnell@suse.de
- adapted parameters of parted resize command to parted 3.1 (part
  of fate#316110)
* Fri Jan 17 2014 aschnell@suse.de
- handle default btrfs subvolume when adding subvolumes to fstab
* Thu Jan 16 2014 aschnell@suse.de
- allow to store userdata for devices (used for fate#316221)
* Thu Jan  9 2014 aschnell@suse.de
- fixed setup of named RAIDs (bnc#849752)
- version 2.25.6
* Mon Dec 16 2013 aschnell@suse.de
- during installation add btrfs subvolumes to fstab (fate#316541)
- version 2.25.5
* Fri Dec 13 2013 aschnell@suse.de
- added support for NVMe devices (see fate#315662)
* Thu Dec 12 2013 aschnell@suse.de
- fixed fstab handling for certain remove operations
* Tue Dec  3 2013 aschnell@suse.de
- added list of UsedByInfo to ruby bindings
- removed deprecated variables from ContainerInfo, VolumeInfo and
  DiskInfo
- pass some variables as list instead of joined string
* Wed Nov 20 2013 aschnell@suse.de
- fixed writing of fstab for installation on NFS (bnc#848038)
* Wed Nov 13 2013 aschnell@suse.de
- use correct binary prefix (bnc#849276)
- version 2.25.3
* Tue Nov  5 2013 aschnell@suse.de
- support label on FAT (bnc#848052)
* Mon Nov  4 2013 aschnell@suse.de
- removed storage_utf8.rb (bnc#848812)
* Tue Oct 29 2013 aschnell@suse.de
- always use mdadm for IMSM and DDF (fate#316007)
- version 2.25.2
* Tue Oct 29 2013 aschnell@suse.de
- added support for rsxx devices (fate#316440)
* Tue Oct 29 2013 aschnell@suse.de
- display partition type not only by number (bnc#844577)
* Wed Oct 23 2013 aschnell@suse.de
- make btrfs the default filesystem (fate#315901)
- version 2.25.1
* Tue Oct 15 2013 aschnell@suse.de
- fixed calculation of free physical extents (bnc#844534)
* Mon Oct 14 2013 aschnell@suse.de
- changed default mount-by to uuid (fate#316204)
* Fri Oct 11 2013 aschnell@suse.de
- adapted to device-mapper device name changes (bnc#810840)
* Mon Sep 30 2013 aschnell@suse.de
- force UTF-8 encoding on ruby string (bnc#841713)
- version 2.25.0
* Wed Sep 25 2013 fehr@suse.de
- version 2.24.5
- add code to support named raids (fate#315590)
* Tue Sep 10 2013 aschnell@suse.de
- removed warning popup during probing about parted not being
  able to read partition table (fate#307585)
- version 2.24.4
* Thu Aug 22 2013 fehr@suse.de
- make additional types known to ruby/python bindings
- version 2.24.3
* Thu Aug 22 2013 aschnell@suse.de
- added udevadm settle call (bnc#836048)
* Mon Aug 12 2013 fehr@suse.de
- remove cruft to support broken ycp bindings
- improvements in ruby bindings for usage in yast2-storage
- version 2.24.2
* Wed Aug  7 2013 fehr@suse.de
- fix progress bar for EXT filesystems
* Tue Jul 23 2013 fehr@suse.de
- remove obsolete empty function initDefaultLogger()
* Wed Jul  3 2013 fehr@suse.de
- allow to fake EFI detection with env var LIBSTORAGE_ENFORCE_EFI
* Wed Jun 19 2013 fehr@suse.de
- version 2.24.1
- adapt to changed functionality of losetup (bnc#825503)
* Mon May 13 2013 fehr@suse.de
- supported label size for swap is 15, not 16 like other fs have
  (bnc#818822)
* Tue May  7 2013 fehr@suse.de
- detects lvm pools also when broken (bnc#818780)
- fixed missing umount of btrfs volume when disk label is removed
  (bnc#818705)
* Tue Apr 23 2013 aschnell@suse.de
- fixed parser for dmsetup output for device names containing a
  colon (bnc#816063)
* Fri Apr 19 2013 fehr@suse.de
- fixed bug with activated encryption on DASDs (bnc#810706)
* Tue Apr 16 2013 fehr@suse.de
- version 2.24.0
- add fast way to detect present disks in system (bnc#810823)
* Thu Mar 28 2013 fehr@suse.de
- fix bug while formatting as btrfs after resizing (bnc#812162)
* Tue Mar 26 2013 fehr@suse.de
- fix wrong handling of shrinking swap (bnc#803800)
- restructured handling of resizing of existing fs
* Tue Mar 19 2013 fehr@suse.de
- fix wrong size calculation when deleting thin LVs (bnc#810305)
* Mon Mar 11 2013 fehr@suse.de
- version 2.23.10
- fix LVM encryption when btrfs fs is present (bnc#808020)
* Wed Mar  6 2013 fehr@suse.de
- improve handling of udev by-id links for dm devices
- fix detect of encrypted volumes (bnc#808487)
* Tue Mar  5 2013 fehr@suse.de
- version 2.23.9
- detect is_efiboot by checking for /sys/firmware/efi (bnc#806490)
- fix handling of encrypted LVM based proposal on partitioned Dm
  and Md devices (bnc#805169)
* Mon Mar  4 2013 fehr@suse.de
- prevent dangling btrfs shadow volumes (bnc#803935)
* Wed Feb 27 2013 fehr@suse.de
- version 2.23.8
- fix handling of inactive raid devices (bnc#798275)
* Thu Feb 21 2013 fehr@suse.de
- version 2.23.7
- fix bug with creation of encrypted LVM on S390 (bnc#804598)
- add y2log entries for source md5sum and source modify date
* Wed Feb 20 2013 fehr@suse.de
- version 2.23.6
- recognize /dev/disk-by-id/dm-name-<nm> as alias to
  /dev/mapper/<dm> (bnc#805169)
* Tue Feb 19 2013 aschnell@suse.de
- use option -f for vgremove (bnc#781402)
* Fri Feb 15 2013 aschnell@suse.de
- version 2.23.5
- detect fake partitions on FBA DASDs (bnc#786164)
* Thu Feb  7 2013 fehr@suse.de
- create partition type "gpt_sync_mbr" instead of plain gpt also
  on ppc architecture (bnc#797485)
* Tue Jan 29 2013 fehr@suse.de
- version 2.23.4
- fixed wrong display of fs type when formatting btrfs (bnc#799897)
* Fri Jan  4 2013 aschnell@suse.de
- do not resize filesystem if enlarging partition failed
  (bnc#796339)
* Wed Dec 19 2012 fehr@suse.de
- version 2.23.3
- change order of vgchange/vgscan call in LvmVg to work around
  udev not creating LVM device nodes any more (bnc#794692)
- add function umountDeviceUns to make YCP able to prevent removal
  of crypt helper devices when doing fstab import (bnc#794692)
* Fri Dec  7 2012 aschnell@suse.de
- escape meta-characters for regular expressions (bnc#792245)
- 2.23.2
* Tue Nov 20 2012 aschnell@suse.de
- updated check for parted errors (bnc#790481)
* Thu Nov 15 2012 aschnell@suse.de
- added another udevadm settle call (bnc#781402)
* Tue Nov 13 2012 fehr@suse.de
- remove boost-devel from Requires of libstorage-devel
* Wed Nov  7 2012 fehr@suse.de
- 2.23.1
- support creation of "BIOS grub" partition on GPT (bnc#786870)
* Mon Nov  5 2012 fehr@suse.de
- freq and passno should be 0 for BTRFS fs in fstab (bnc#786719)
* Tue Oct 16 2012 fehr@suse.de
- ignore failed partition removal if partition table is later
  initialized anyway (bnc#785234)
* Thu Aug 30 2012 fehr@suse.de
- 2.23.0
- first final implementation of thin provisioning in LVM
* Thu Aug 23 2012 fehr@suse.de
- add code for detection and handling of thin provisioning in LVM
* Tue Aug 14 2012 aschnell@suse.de
- 2.22.11
- allow mount-by label and uuid for NTFS (bnc#775594)
* Mon Aug 13 2012 fehr@suse.de
- 2.22.10
- rename dm maps according to crypttab during update (bnc#774247)
* Tue Aug  7 2012 fehr@suse.de
- 2.22.9
- use mount point as base for dm name if available (bnc#768572)
* Thu Aug  2 2012 fehr@suse.de
- fix handling of LVMs with mix of encrypted and unencrypted PVs
- fix handling of encrypted PVs with non-standard dm name
* Tue Jul 24 2012 fehr@suse.de
- improve handling of btrfs on non-formatted root fs
* Mon Jul 23 2012 fehr@suse.de
- fix uuid handling when changing format false->true->false for
  btrfs filesystems (bnc#772112)
* Mon Jul 16 2012 aschnell@suse.de
- 2.22.8
- increased major number of library (bnc#771641)
* Wed Jun 27 2012 fehr@suse.de
- 2.22.7
- add function to replace complete list of md component devices
* Tue Jun 26 2012 fehr@suse.de
- suppress helper dm maps for lvm pool and lvm raid volumes
* Mon Jun 18 2012 fehr@suse.de
- 2.22.6
- check for existence of all used binaries
* Tue Jun 12 2012 fehr@suse.de
- 2.22.5
- get rid of usage of blocxx for logging purposes
* Tue May 29 2012 fehr@suse.de
- 2.22.4
- fix building of ruby bindings
* Wed May 16 2012 fehr@suse.de
- 2.22.3
- use udev_id for base name of encrypted dm map instead of device
  name (bnc#760213)
* Tue May  8 2012 fehr@suse.de
- fix bug formatting a mounted btrfs volume as non-btrfs (bnc#755704)
* Wed May  2 2012 fehr@suse.de
- 2.22.2
- add code to support resizing of a btrfs volume (bnc#731753)
* Thu Apr  5 2012 fehr@suse.de
- suppress dm maps for "-real" and "-cow" of LVM snapshots in
  general Dm container
- fix order of LV removals in removeVg when snapshots are present
  (bnc#755021)
* Mon Apr  2 2012 aschnell@suse.de
- calculate max_primary for artificial XEN disks (bnc#754649)
* Thu Mar 15 2012 aschnell@suse.de
- fixes for gcc 4.7
- 2.22.1
* Mon Mar 12 2012 fehr@suse.de
- tell in resize text that it may potentially need very long to
  complete and that one must not abort while resize is running
  (bnc#749946)
* Mon Mar 12 2012 aschnell@suse.de
- removed deactivation of MD RAIDs using DM during installation
  (bnc#751780)
* Tue Mar  6 2012 fehr@suse.de
- do not detect loop device with range>1 as disks
* Tue Jan 31 2012 aschnell@suse.de
- add by-id names to alt-names of DmPartCo (bnc#744194)
* Wed Jan 25 2012 fehr@suse.de
- allow resize and move of simple btrfs volumes if they are
  formatted anyway (bnc#742491)
* Tue Jan 24 2012 fehr@suse.de
- fix bug introduced with second to last commit
- make sure error popup contains always valid info
- remove btrfs volumes when partition table gets destroyed (bnc#742491)
* Tue Jan 24 2012 aschnell@suse.de
- added interface to control autostarting of multipath (bnc#742913)
* Tue Jan 24 2012 fehr@suse.de
- complete renaming of devs in Btrfs class (bnc#742491)
- fix bug in btrfs uuid handling introduced in 2.17.124 (bnc#742491)
* Fri Jan 20 2012 aschnell@suse.de
- fixed read-only mount of volumes for resize information detection
  (bnc#736098)
* Wed Jan 11 2012 fehr@suse.de
- fix bug when extending a btrfs fs that had format set (bnc#732988)
- fix problem handling used by for btrfs during extend
* Wed Dec 21 2011 aschnell@suse.de
- handle FBA DASD with parted instead of fdasd (bnc#584703)
* Tue Dec 20 2011 aschnell@suse.de
- ask user to activate multipath if setup appears to be multipath
  (see bnc#727428 and bnc#735038)
* Tue Dec  6 2011 aschnell@suse.de
- add function getResursiveUsedBy (for bnc#734786)
- make getResursiveUsing also take a list as input
* Wed Nov 23 2011 aschnell@suse.de
- add name in /dev/md/ to alt-names of partitioned RAID
  (bnc#726319)
* Tue Nov 22 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Fri Nov 18 2011 aschnell@suse.de
- merged proofread texts
* Thu Nov 17 2011 fehr@suse.de
- create btrfs subvolumes before mounting (bnc#731059)
* Tue Nov 15 2011 fehr@suse.de
- try umount in mountTmpMount by dir first to handle cases where
  same device is mounted multiple times
* Wed Nov  9 2011 aschnell@suse.de
- avoid detection on volumes on disk used by other stuff (bnc#729155)
- fixed NFS detection (bnc#729155)
- improved multipath parser (see bnc#727428)
- 2.22.0
* Mon Nov  7 2011 fehr@suse.de
- 2.21.15
- fix crash when deleting multipath volumes (bnc#725695)
* Thu Nov  3 2011 fehr@suse.de
- 2.21.14
- fix fstab handling when mount-by-uuid is reformatted (bnc#728000)
- add local static struct to getContVolInfo to prevent strings
  from being freed while perl interface might still access them
* Mon Oct 31 2011 fehr@suse.de
- 2.21.13
- improve detection of /home partition (bnc#727362)
* Wed Oct 26 2011 fehr@suse.de
- 2.21.12
- make /dev/md/ names known to libstorage if present (bnc#726319)
- do not set fsck flag to zero for encrypted volumes (bnc#726414)
* Tue Oct 25 2011 fehr@suse.de
- 2.21.11
- changes to support new function IsDeviceOnNetwork in ycp
* Mon Oct 24 2011 fehr@suse.de
- detect new transport type FCoE (bnc#726057)
* Tue Oct 18 2011 fehr@suse.de
- 2.21.10
- prevent missing swap entry in fstab when swap already active at
  start of installation (bnc#724785)
* Wed Oct 12 2011 aschnell@suse.de
- updated translations
- 2.21.9
* Mon Sep 19 2011 fehr@suse.de
- version 2.21.8
- fix bug that prevent mounting by-id and by-path for BTRFS volumes
  (bnc#718717)
* Tue Sep 13 2011 fehr@suse.de
- version 2.21.7
- add examples for ruby and python usage to devel package
- add ruby bindings to libstorage
- make functions returning data via non-const references usable
  in python (bnc#717323)
* Wed Sep  7 2011 fehr@suse.de
- version 2.21.6
- ignore btrfs fs when blockid does not see also btrfs (bnc#716058)
- call zeroDevice always before formatting to prevent multiple
  signatures being present (bnc#716058)
- use wipefs to remove any existing signatures in zeroDevice
* Mon Sep  5 2011 fehr@suse.de
- fix detection of mount by label on btrfs
- use "btrfs filesystem label" to handle label on btrfs
* Mon Sep  5 2011 aschnell@suse.de
- handle device name change in btrfs (bnc#715652)
* Tue Aug 30 2011 aschnell@suse.de
- fixed setting of size for partitions on MD RAID (bnc#714397)
* Wed Aug 24 2011 fehr@suse.de
- use new "gpt_sync_mbr" only on non-EFI systems, on EFI systems
  plain "gpt" is used (bnc#710402)
- version 2.21.5
* Tue Aug 23 2011 fehr@suse.de
- add option "-P _part" to make dmraid deactivate raid (bnc#712671)
* Wed Aug 10 2011 fehr@suse.de
- support label on btrfs
- version 2.21.4
* Tue Aug  9 2011 fehr@suse.de
- fix bugs in subvolume handling during install
* Fri Aug  5 2011 aschnell@suse.de
- moved lock file to /var/run/libstorage (bnc#710356)
* Thu Aug  4 2011 fehr@suse.de
- avoid crash when btrfs signature is on disk device (bnc#710043)
* Tue Aug  2 2011 fehr@suse.de
- call waitForDevice in checkDevice to work around possible
  temporary device node removal by udev (bnc#709464)
* Thu Jul 28 2011 fehr@suse.de
- changes needed to fix bnc#707472
* Tue Jul 26 2011 aschnell@suse.de
- fixed commit action calculation for DASDs (bnc#706911)
* Tue Jul 19 2011 aschnell@suse.de
- fixed size calculation for very small partitions (bnc#705566)
* Tue Jul 19 2011 fehr@suse.de
- fix failing testsuite if program without setup_system is first
* Wed Jul  6 2011 fehr@suse.de
- fix bug when setting mount point and changing fstype from
  non-btrfs to btrfs and vice versa
* Tue Jul  5 2011 aschnell@suse.de
- provide defines with version info
* Fri Jun 17 2011 aschnell@suse.de
- updated translations
* Thu Jun  9 2011 fehr@suse.de
- add functionality to have everything in a default btrfs subvol
  (additions to fate#306587)
- version 2.21.3
* Fri May 27 2011 coolo@novell.com
- fix package rename
* Thu May 26 2011 fehr@suse.de
- more btrfs related bugfixes
* Thu May 26 2011 aschnell@suse.de
- adapted to parted 2.4
- 2.21.2
* Thu May 12 2011 fehr@suse.de
- fix missing crypttab entry in installed system (bnc#693325)
- 2.21.1
* Thu Apr 21 2011 fehr@suse.de
- add support for tmpfs (fate#303810)
* Thu Mar 24 2011 fehr@suse.de
- add code to add/remove volumes to/from BTRFS volume
* Thu Mar  3 2011 fehr@suse.de
- bugfixes and improvements in BTRFS handling
* Wed Feb 16 2011 aschnell@suse.de
- make temporary mounts more robust (see bnc #672118)
* Thu Feb  3 2011 fehr@suse.de
- add options provided in addNfs call to volume automatically
* Tue Jan 18 2011 fehr@suse.de
- display text about formatting also if partition is resized
  (bnc #661953)
* Tue Dec  7 2010 aschnell@suse.de
- use single parted command to set partition flags (bnc #657360)
- 2.20.6
* Wed Nov  3 2010 fehr@suse.de
- fixed wrong computation of free cylinders after partition
  (bnc #650966)
- 2.20.5
* Mon Oct 25 2010 aschnell@suse.de
- fixed handling of device name with spaces in /etc/fstab
  (bnc #648878)
- 2.20.4
* Mon Sep 27 2010 aschnell@suse.de
- fixed detection of spare devices for MD RAID
- extended interface to allow creation of MD RAIDs with spare
  devices, corresponding functions need additional parameter
- 2.20.3
* Wed Sep 15 2010 aschnell@suse.de
- added subpackage libstorage-testsuite
- 2.20.2
* Mon Aug  9 2010 fehr@suse.de
- add handling of multiple -O options for ext3/ext4 (bnc#629363)
* Wed Aug  4 2010 aschnell@suse.de
- added transport type from lsscsi to hard disks
- 2.20.1
* Thu Jul 29 2010 fehr@suse.de
- improve volume search when reading fstab
* Wed Jul 21 2010 aschnell@suse.de
- recheck activation of multipath before rescan
* Tue Jul 20 2010 fehr@suse.de
- add support for additional parity values for raid5, raid6, raid10
- add new interface function getMdAllowedParity
* Mon Jul  5 2010 aschnell@suse.de
- moved EFI detection from YCP to C++ (bnc #612867)
* Thu Jul  1 2010 fehr@suse.de
- check mode of /tmp and /var/tmp after mounting (bnc #591704)
- 2.20.0
* Fri Jun 11 2010 aschnell@suse.de
- updated translations
- 2.19.16
* Fri May 14 2010 aschnell@suse.de
- updated translations
- 2.19.15
* Wed May 12 2010 aschnell@suse.de
- make defaultDiskLabel depend on logical sector size
* Wed May 12 2010 aschnell@suse.de
- respect partition table limitations in getUnusedPartitionSlots
  and freeCylindersAroundPartition
* Thu May  6 2010 fehr@suse.de
- remove enforcement to call addpart
* Wed May  5 2010 fehr@suse.de
- call xfs_check instead of fsck -n -t xfs since /sbin/fsck is
  missing in installation environment (bnc #601531)
* Tue May  4 2010 fehr@suse.de
- call mkswap with option -f otherwise it sometime refuses to create
  swap signature
* Thu Apr 29 2010 fehr@suse.de
- fix handling of multiple xbd devices with same basename
  (e.g. xvda1,xvda2) bnc #587658
- ignore changes of partition id on readonly disks
* Mon Apr 26 2010 fehr@suse.de
- make alignment of created partitions configurable (optimal,cylinder)
  to be able to work around problems like in bnc #597723
* Fri Apr  9 2010 aschnell@suse.de
- allow mount-by id for unpartitioned MDs
- 2.19.14
* Thu Apr  8 2010 aschnell@suse.de
- fixed mount-by id for partitioned MDs (bnc #594347)
* Thu Apr  1 2010 aschnell@suse.de
- show size in create text for volume group
* Mon Mar 29 2010 aschnell@suse.de
- handle logical sector sizes unequal 512 bytes
- 2.19.13
* Fri Mar 26 2010 aschnell@suse.de
- fixed setting password for encrypted LVM proposal (bnc #591075)
* Thu Mar 25 2010 fehr@suse.de
- fix problems with detection of data on newly unlocked encrypted
  volumes (bnc #581341)
* Mon Mar 22 2010 aschnell@suse.de
- fixed DEVICE line in mdadm.conf (bnc #590237)
* Thu Mar 18 2010 fehr@suse.de
- make update and detection of encrypted LVM VGs possible
- 2.19.12
* Wed Mar 17 2010 aschnell@suse.de
- improved commit messages for partitioned MDs
* Wed Mar 17 2010 fehr@suse.de
- do no fsck after successful luksOpen, it's unnecessary (bnc #588698)
* Tue Mar  9 2010 aschnell@suse.de
- add AUTO line in mdadm.conf for iSCSI systems (fate #307478)
- 2.19.11
* Fri Mar  5 2010 aschnell@suse.de
- fixed member entry in mdadm.conf for IMSM (bnc #576498)
* Wed Mar  3 2010 aschnell@suse.de
- wait for device before zeroing it (bnc #584683)
* Mon Mar  1 2010 aschnell@suse.de
- changed format of info file to XML
* Tue Feb 23 2010 fehr@suse.de
- fix wrong handling of fstab entry when removing mount point of
  encrypted device
- make conversion of mounted volume into a LVM PV work
- do not add "noauto" to encrypted fstab entries any more (bnc #581339)
- 2.19.10
* Tue Feb 23 2010 aschnell@suse.de
- deactivate and reactivate storage systems before rescan devices
  (bnc #571828)
* Mon Feb 22 2010 fehr@suse.de
- prevent mis-detection of end of gap when creating partitions
* Fri Feb 19 2010 aschnell@suse.de
- allow setting of imsm_driver via env.var. (bnc #574270)
* Tue Feb 16 2010 aschnell@suse.de
- fixed seg. fault during installation with MD RAIDs
* Wed Feb 10 2010 fehr@suse.de
- provide name of encrypted dm device in VolumeInfo (bnc #577127)
- 2.19.9
* Tue Feb  9 2010 fehr@suse.de
- adaptions for new parted 2.1
  if ioctl BLKRRPART from parted fails, call addpart/delpart to
  still allow repartitioning of disks where partitions are busy
- 2.19.8
* Mon Feb  8 2010 aschnell@suse.de
- fixes for g++ 4.5
* Thu Feb  4 2010 aschnell@suse.de
- fixed writing of mdadm.conf (bnc #565207)
- 2.19.7
* Wed Jan 27 2010 fehr@suse.de
- add "nofail" to dm-encrypted fstab entries and do not set passno
  to zero any more (bnc #569895)
* Wed Jan 27 2010 aschnell@suse.de
- allow to set driver for IMSM without callback (bnc #574270)
* Mon Jan 25 2010 aschnell@suse.de
- fixed default mount-by for multipath (bnc #572209)
* Thu Jan 21 2010 aschnell@suse.de
- replaced function freeCylindersAfterPartition by
  freeCylindersAroundPartition
- 2.19.6
* Tue Jan 19 2010 aschnell@suse.de
- zero newly created partitions on DASDs (bnc #571828)
* Tue Jan 19 2010 fehr@suse.de
- allow to use cylinder 0 for partition (bnc #571749)
* Mon Jan 18 2010 aschnell@suse.de
- added NFS4 support (fate #305171)
* Mon Jan 18 2010 aschnell@suse.de
- added getErrorString function (bnc #546012)
* Fri Jan 15 2010 aschnell@suse.de
- allow to ignore failures during commit (fate #304500)
* Wed Jan 13 2010 fehr@suse.de
- add detected fs to volume data provided for YCP interface (bnc
  [#457100])
- 2.19.5
* Mon Jan 11 2010 fehr@suse.de
- added function getRecursiveUsing to determine transitive closure
  of volumes affected by removal of a device
* Fri Jan  8 2010 aschnell@suse.de
- fixed numbering of RAIDs (bnc #567662)
* Fri Jan  8 2010 aschnell@suse.de
- improved getFreeInfo to allow only querying of certain data
* Tue Dec 29 2009 aschnell@suse.de
- ported MdPart code from SLE11 SP1
- 2.19.4
* Tue Dec 15 2009 fehr@suse.de
- fix detection of existing file based loop devices
- fix edit mode for existing file based loop devices (bnc #480736)
* Fri Dec 11 2009 aschnell@suse.de
- give all info files the extension .info
* Thu Dec 10 2009 fehr@suse.de
- add capability to verify passwords of file based loop devices
* Thu Dec 10 2009 fehr@suse.de
- do some changes in handling of encrypted passwords (fixing bnc
  [#466196] and #480739)
- use "crypt" fstab entry when "user" is set, not any more when
  "noauto" set
* Wed Dec  9 2009 aschnell@suse.de
- added saving and loading of freeinfo and arch
* Tue Dec  8 2009 aschnell@suse.de
- added check for home partitions in getFreeInfo
- 2.19.3
* Tue Dec  8 2009 fehr@suse.de
- fix handling of inactive swap file entry in fstab (bnc #504497)
* Tue Dec  8 2009 fehr@suse.de
- fix detection of encrypted swap and temp filesystems (bnc
  [#435337])
- fix various bugs handling encrypted devices
* Thu Dec  3 2009 aschnell@suse.de
- log untranslated messages
- 2.19.2
* Thu Dec  3 2009 fehr@suse.de
- avoid data loss on encrypted partitions using non-LUKS encryption
  when integrating them into system (bnc #557607)
* Wed Dec  2 2009 aschnell@suse.de
- removed call to devmap_mknod.sh (which has disappeared)
* Fri Nov 27 2009 aschnell@suse.de
- adapted parser for multipath output
* Wed Nov 25 2009 aschnell@suse.de
- read testmode file for LVM VGs
* Tue Nov 24 2009 fehr@suse.de
- enabled to set "noauto" option for LUKS-encrypted volumes
* Mon Nov 23 2009 aschnell@suse.de
- improved parsing of dmsetup output
* Fri Nov 20 2009 aschnell@suse.de
- added mount graph
- 2.19.1
* Thu Nov 19 2009 fehr@suse.de
- fixed freeCylindersAfterPartition when start of next partition
  is on same cylinder than end of current (bnc #465370)
* Wed Nov 18 2009 aschnell@suse.de
- run dmraid and multipath only once during detection
* Tue Nov 17 2009 aschnell@suse.de
- improved XEN VBD detection (bnc #365688)
* Mon Nov 16 2009 aschnell@suse.de
- use name instead of device as label in nodes of graph
* Wed Nov 11 2009 aschnell@suse.de
- fixed return value of function getContVolInfo
* Mon Nov  9 2009 fehr@suse.de
- preserve label when unsetting format flag (bnc #537064)
* Mon Nov  9 2009 aschnell@suse.de
- always use ntfs-3g for NTFS volumes since ntfs is not supported
  by the kernel anymore
* Wed Oct 28 2009 aschnell@suse.de
- converted usedby information to list (bnc #472812)
- 2.19.0
* Fri Oct 16 2009 aschnell@suse.de
- log mdadm.conf created during scan (bnc #547288)
* Wed Oct 14 2009 aschnell@suse.de
- do not detect MDs as disks (bnc #546912)
- 2.18.23
* Mon Oct 12 2009 aschnell@suse.de
- added copyright text to source files (bnc #545744)
* Thu Oct  1 2009 aschnell@suse.de
- fixed fstab entries for existing encrypted volumes (bnc #530173)
- 2.18.22
* Tue Sep 29 2009 aschnell@suse.de
- fixed setting encryption for existing devices (bnc #539104)
* Fri Aug 28 2009 aschnell@suse.de
- fixed handling of efiboot parameter (bnc #490782)
* Mon Aug 17 2009 aschnell@suse.de
- fixed reading sysfs info for Compaq Intelligent Drive Array
  (bnc #531568)
* Thu Aug 13 2009 aschnell@suse.de
- improved handling of special characters in filesystem labels
  (bnc #414294)
* Tue Aug 11 2009 aschnell@suse.de
- added getPartitionPrefix() to interface
- 2.18.21
* Sun Aug  9 2009 coolo@novell.com
- use new python macros
* Wed Jul 29 2009 aschnell@suse.de
- fixed removing encrypted pvs from vg
* Tue Jul 28 2009 aschnell@suse.de
- fix for mmcblk devices
* Fri Jul 24 2009 aschnell@suse.de
- work on extended block devt (fate #305584)
- added extendedPossible to DiskInfo
- 2.18.20
* Thu Jul 23 2009 aschnell@suse.de
- added minimal experimental btrfs support, esp. filesystems over
  multiple devices are not supported (fate #306587)
- 2.18.19
* Thu Jul 23 2009 aschnell@suse.de
- set ignore_fstab also for non NFS volumes not listed in
  /etc/fstab (fate #305150)
* Fri Jul 17 2009 aschnell@suse.de
- run swapon with option --fixpgsz (requires util-linux 2.16)
* Thu Jul 16 2009 aschnell@suse.de
- support naming of mmcblk devices (fate #305312)
- added getPartitionName() to interface
- 2.18.18
* Wed Jul 15 2009 aschnell@suse.de
- use "Arial" in storage graph (see bnc #508092)
* Thu Jul  9 2009 aschnell@suse.de
- work on full disk encryption (fate #305633)
- 2.18.17
* Mon Jul  6 2009 aschnell@suse.de
- updated translations
* Tue Jun 16 2009 aschnell@suse.de
- automake 1.11 fix
* Wed Jun 10 2009 aschnell@suse.de
- added python bindings
* Wed Jun 10 2009 aschnell@suse.de
- added translations
* Mon Jun  8 2009 aschnell@suse.de
- added callback for password query
- 2.18.16
* Fri Jun  5 2009 aschnell@suse.de
- added complete GPL text (bnc #510349)
- 2.18.15
* Thu Jun  4 2009 aschnell@suse.de
- do not report partitions for disks used by BIOS RAID or DM
  Multipath
- added functions setDefaultFs() and getDefaultFs()
- 2.18.14
* Tue Jun  2 2009 aschnell@suse.de
- split off libstorage from yast2-storage
- 2.18.13
